OpenCensus PostgreSQL Integration
============================================================================

|pypi|

.. |pypi| image:: https://badge.fury.io/py/opencensus-ext-postgresql.svg
   :target: https://pypi.org/project/opencensus-ext-postgresql/

The integration with PostgreSQL supports the `psycopg2`_ library and is specified
to ``trace_integrations`` using ``'postgresql'``.

.. _psycopg2: https://pypi.org/project/psycopg2

Installation
------------

::

    pip install opencensus-ext-postgresql

Usage
-----

.. code:: python

    from opencensus.trace import config_integration

    config_integration.trace_integrations(['postgresql'])

References
----------

* `OpenCensus Project <https://opencensus.io/>`_
